@@ -14,6 +14,7 @@ import os.path
 import tarfile
 from getpass import getpass
 from pathlib import Path
+from typing import Optional
 
 import click
 from rich import print
@@ -150,12 +151,12 @@ def deploy(_: Info, path: str, url: str, org: str, token: str):
 
 @cli.command()
 @click.argument('object_type', required=True)
-@click.argument('ref', required=True)
+@click.argument('ref', required=False)
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @click.option('--path', default=None, help='JQ path to content you want')
 @pass_info
-def get(_: Info, object_type: str, ref: str, url: str, token: str, path: str = None):
+def get(_: Info, object_type: str, ref: Optional[str], url: str, token: str, path: str = None):
     """
     List the instance of the object type
     """
@@ -164,6 +165,21 @@ def get(_: Info, object_type: str, ref: str, url: str, token: str, path: str = N
     KodexaPlatform.get(object_type, ref, path)
 
 
+@cli.command()
+@click.argument('ref', required=True)
+@click.argument('query', default="*")
+@click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
+@click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
+@click.option('--download/--no-download', default=False, help='Download the KDDB for the lastest in the family')
+@click.option('--page', default=1, help='Page number')
+@click.option('--pageSize', default=10, help='Page size')
+@pass_info
+def query(_: Info, query: str, ref: str, url: str, token: str, download: bool, page: int, pagesize: int):
+    KodexaPlatform.set_url(url)
+    KodexaPlatform.set_access_token(token)
+    KodexaPlatform.query(ref, query, download, page, pagesize)
+
+
 @cli.command()
 @click.argument('object_type', required=True)
 @click.argument('ref', required=True)
