@@ -51,8 +51,7 @@ class Tag(Dict):
 
     def __init__(self, start: Optional[int] = None, end: Optional[int] = None, value: Optional[str] = None,
                  uuid: Optional[str] = None, data: Any = None, *args, confidence: Optional[float] = None,
-                 index: Optional[int] = None,
-                 **kwargs):
+                 index: Optional[int] = None, bbox: Optional[List[int]] = None, **kwargs):
         super().__init__(*args, **kwargs)
         self.start: Optional[int] = start
         """The start position (zero indexed) of the content within the node, if None then label is applied to the whole node"""
@@ -68,6 +67,8 @@ class Tag(Dict):
         """The confidence of the tag in a range of 0-1"""
         self.index: Optional[int] = index
         """The tag index, this is used to allow us to order tags, and understand the ordering of parent child tag relationships"""
+        self.bbox: Optional[List[int]] = bbox
+        """The optional bounding box that can be used if the label is spatial (based on the node as the container)"""
 
 
 class FindDirection(Enum):
@@ -2418,6 +2419,7 @@ class DocumentStore(Store):
             The last document to be stored in the family or None if there isn't one available
 
         """
+        document_family.content_objects.sort(key=lambda x: x.created_on, reverse=False)
         last_co = document_family.content_objects[-1]
         document = self.get_document_by_content_object(document_family, last_co)
 
